@@ -10,7 +10,6 @@ __docformat__ = "reStructureText"
 
 import numpy as np
 import datetime
-import apexpy
 
 import geospacelab.datahub as datahub
 from geospacelab.datahub import DatabaseModel, FacilityModel, InstrumentModel, ProductModel
@@ -179,7 +178,7 @@ class Dataset(datahub.DatasetSourced):
         self['SC_AACGM_MLT'].value = cs_aacgm['mlt'].reshape(self['SC_DATETIME'].value.shape)
 
     def fix_geo_lon(self):
-        from geospacelab.observatory.sc_orbit import OrbitPosition_SSCWS
+        from geospacelab.observatory.orbit.sc_orbit import OrbitPosition_SSCWS
         from scipy.interpolate import interp1d
         # check outliers
         orbit_obj = OrbitPosition_SSCWS(
